@@ -1,5 +1,4 @@
-`psclose` <-
-function(file=getOption("gmt.file"), trailer=TRUE, cleanup=TRUE)
+psclose <- function(file=getOption("gmt.file"), trailer=TRUE, cleanup=TRUE)
 {
   if(is.null(file)) stop("Please pass a valid 'file' argument, or run gmt(file=\"myfile\").")
   owd <- setwd(dirname(file)); on.exit(setwd(owd))
@@ -31,4 +30,3 @@ function(file=getOption("gmt.file"), trailer=TRUE, cleanup=TRUE)
 
   invisible(NULL)
 }
-
